@@ -1,10 +1,12 @@
 #ifndef WMGENERAL_H_INCLUDED
 #define WMGENERAL_H_INCLUDED
 
-
+#include <X11/X.h>
+#include <X11/Xlib.h>
+#include <X11/xpm.h>
 
 /*
- *   Typedefs 
+ *   Typedefs
  */
 typedef struct {
 	Pixmap		pixmap;
@@ -21,7 +23,7 @@ typedef struct {
 Display		*display;
 Window          Root;
 Window          iconwin, win;
-int             screen; 
+int             screen;
 int             DisplayDepth;
 
 
